@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2004, 2007, 2009, 2010  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2011, 2012, 2014  Internet Systems Consortium, Inc. ("ISC")
 #
 # Permission to use, copy, modify, and/or distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -14,16 +14,12 @@
 # OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 # PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: sign.sh,v 1.3.4.2 2011-05-27 00:43:05 each Exp $
-
-(cd ../ns3 && sh -e ./sign.sh || exit 1)
-
-echo "I:dlv/ns2/sign.sh"
-
 SYSTEMTESTTOP=../..
 . $SYSTEMTESTTOP/conf.sh
 
-RANDFILE=../random.data
+(cd ../ns3 && $SHELL -e ./sign.sh || exit 1)
+
+echo "I:dlv/ns2/sign.sh"
 
 zone=druz.
 infile=druz.db.in
