@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2004, 2007, 2011-2013  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2004, 2007, 2011-2013, 2016  Internet Systems Consortium, Inc. ("ISC")
 # Copyright (C) 2000, 2001  Internet Software Consortium.
 #
 # Permission to use, copy, modify, and/or distribute this software for any
@@ -29,7 +29,7 @@ for i in 1 2 3 4 5 6 7 8 9 10 11 12
 do
 	ret=0
 	$DIG +short $DIGOPTS @10.53.0.1 a$i.example a in > dig.out || ret=1
-	echo 10.0.0.1 | diff - dig.out || ret=1
+	echo 10.0.0.1 | $DIFF - dig.out || ret=1
 	if [ $ret != 0 ]
 	then
 		echo "#$i failed"
@@ -42,7 +42,7 @@ for i in 1 2 3 4 5 6 7
 do
 	ret=0
 	$DIG +short $DIGOPTS @10.53.0.1 txt$i.example txt in > dig.out || ret=1
-	echo '"hello"' | diff - dig.out || ret=1
+	echo '"hello"' | $DIFF - dig.out || ret=1
 	if [ $ret != 0 ]
 	then
 		echo "#$i failed"
@@ -55,7 +55,7 @@ for i in 1 2 3
 do
 	ret=0
 	$DIG +short $DIGOPTS @10.53.0.1 unk$i.example type123 in > dig.out || ret=1
-	echo '\# 1 00' | diff - dig.out || ret=1
+	echo '\# 1 00' | $DIFF - dig.out || ret=1
 	if [ $ret != 0 ]
 	then
 		echo "#$i failed"
@@ -66,14 +66,14 @@ done
 echo "I:querying for NULL record"
 ret=0
 $DIG +short $DIGOPTS @10.53.0.1 null.example null in > dig.out || ret=1
-echo '\# 1 00' | diff - dig.out || ret=1
+echo '\# 1 00' | $DIFF - dig.out || ret=1
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
 echo "I:querying for empty NULL record"
 ret=0
 $DIG +short $DIGOPTS @10.53.0.1 empty.example null in > dig.out || ret=1
-echo '\# 0' | diff - dig.out || ret=1
+echo '\# 0' | $DIFF - dig.out || ret=1
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
@@ -82,7 +82,7 @@ for i in 1 2
 do
 	ret=0
 	$DIG +short $DIGOPTS @10.53.0.1 a$i.example a class10 > dig.out || ret=1
-	echo '\# 4 0A000001' | diff - dig.out || ret=1
+	echo '\# 4 0A000001' | $DIFF - dig.out || ret=1
 	if [ $ret != 0 ]
 	then
 		echo "#$i failed"
@@ -95,7 +95,7 @@ for i in 1 2 3 4
 do
 	ret=0
 	$DIG +short $DIGOPTS @10.53.0.1 txt$i.example txt class10 > dig.out || ret=1
-	echo '"hello"' | diff - dig.out || ret=1
+	echo '"hello"' | $DIFF - dig.out || ret=1
 	if [ $ret != 0 ]
 	then
 		echo "#$i failed"
@@ -108,7 +108,7 @@ for i in 1 2
 do
 	ret=0
 	$DIG +short $DIGOPTS @10.53.0.1 unk$i.example type123 class10 > dig.out || ret=1
-	echo '\# 1 00' | diff - dig.out || ret=1
+	echo '\# 1 00' | $DIFF - dig.out || ret=1
 	if [ $ret != 0 ]
 	then
 		echo "#$i failed"
@@ -132,14 +132,14 @@ done
 echo "I:checking large unknown record loading on master"
 ret=0
 $DIG $DIGOPTS @10.53.0.1 +tcp +short large.example TYPE45234 > dig.out || { ret=1 ; echo I: dig failed ; }
-diff -s large.out dig.out > /dev/null || { ret=1 ; echo "I: diff failed"; }
+$DIFF -s large.out dig.out > /dev/null || { ret=1 ; echo "I: $DIFF failed"; }
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
 echo "I:checking large unknown record loading on slave"
 ret=0
 $DIG $DIGOPTS @10.53.0.2 +tcp +short large.example TYPE45234 > dig.out || { ret=1 ; echo I: dig failed ; }
-diff -s large.out dig.out > /dev/null || { ret=1 ; echo "I: diff failed"; }
+$DIFF -s large.out dig.out > /dev/null || { ret=1 ; echo "I: $DIFF failed"; }
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
@@ -150,14 +150,14 @@ $PERL $SYSTEMTESTTOP/start.pl --noclean --restart . ns2
 echo "I:checking large unknown record loading on slave"
 ret=0
 $DIG $DIGOPTS @10.53.0.2 +tcp +short large.example TYPE45234 > dig.out || { ret=1 ; echo I: dig failed ; }
-diff -s large.out dig.out > /dev/null || { ret=1 ; echo "I: diff failed"; }
+$DIFF -s large.out dig.out > /dev/null || { ret=1 ; echo "I: $DIFF failed"; }
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
 echo "I:checking large unknown record loading on inline slave"
 ret=0
 $DIG $DIGOPTS @10.53.0.3 +tcp +short large.example TYPE45234 > dig.out || { ret=1 ; echo I: dig failed ; }
-diff large.out dig.out > /dev/null || { ret=1 ; echo "I: diff failed"; }
+$DIFF large.out dig.out > /dev/null || { ret=1 ; echo "I: $DIFF failed"; }
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
@@ -168,21 +168,21 @@ $PERL $SYSTEMTESTTOP/start.pl --noclean --restart . ns3
 echo "I:checking large unknown record loading on inline slave"
 ret=0
 $DIG $DIGOPTS @10.53.0.3 +tcp +short large.example TYPE45234 > dig.out || { ret=1 ; echo I: dig failed ; }
-diff large.out dig.out > /dev/null || { ret=1 ; echo "I: diff failed"; }
+$DIFF large.out dig.out > /dev/null || { ret=1 ; echo "I: $DIFF failed"; }
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
 echo "I:check that '"'"\\#"'"' is not treated as the unknown escape sequence"
 ret=0
 $DIG $DIGOPTS @10.53.0.1 +tcp +short txt8.example txt > dig.out
-echo '"#" "2" "0145"' | diff - dig.out || ret=1
+echo '"#" "2" "0145"' | $DIFF - dig.out || ret=1
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
 echo "I:check that 'TXT \# text' is not treated as the unknown escape sequence"
 ret=0
 $DIG $DIGOPTS @10.53.0.1 +tcp +short txt9.example txt > dig.out
-echo '"#" "text"' | diff - dig.out || ret=1
+echo '"#" "text"' | $DIFF - dig.out || ret=1
 [ $ret = 0 ] || echo "I: failed"
 status=`expr $status + $ret`
 
@@ -196,4 +196,4 @@ status=`expr $status + $ret`
 
 
 echo "I:exit status: $status"
-exit $status
+[ $status -eq 0 ] || exit 1
